@@ -26,26 +26,32 @@ def transform(color, transvalue):
 		clist = list(color)
 		translist = list(transvalue)
 
-		clist[0] += translist[0]
-		clist[1] += translist[1]
-		clist[2] += translist[2]
+		if (clist[0] + translist[0]) >= 0:
+			clist[0] += translist[0]
+		if (clist[1] + translist[1]) >= 0:
+			clist[1] += translist[1]
+		if (clist[2] + translist[2]) >= 0:
+			clist[2] += translist[2]
 
 		return tuple(clist)
 
 	if type(transvalue) == int:
 		clist = list(color)
 
-		clist[0] += transvalue
-		clist[1] += transvalue
-		clist[2] += transvalue
+		if (clist[0] + transvalue) >= 0:
+			clist[0] += transvalue
+		if (clist[1] + transvalue) >= 0:
+			clist[1] += transvalue
+		if (clist[2] + transvalue) >= 0:
+			clist[2] += transvalue
 
 		return tuple(clist)		
 
 def help():
-	print('	Colors module help:')
-	print('		importing: "import colors" or "from colors import *"')
-	print('		get rgb of color: "colors.<color>"')
-	print('		transform color: "colors.transform(<rgb tuple>, <3-value tuple or int>)')
-	print('		transform color will return a scaled/transformed color. 2nd arg is the added value (3-value tuple or int)')
+	print('Colors module help:')
+	print('	importing: "import easycolors" or "from easycolors import *"')
+	print('	get rgb of color: "easycolors.<color>"')
+	print('	transform color: "easycolors.transform(<rgb tuple>, <3-value tuple or int>)')
+	print('	transform color will return a scaled/transformed color. 2nd arg is the added value (3-value tuple or int)')
 
-print('Thanks for using the Colors module! Run "print(colors.help)" for help.')
\ No newline at end of file
+print('Thanks for using the easycolors module! Run "easycolors.help()" for help.')
\ No newline at end of file
